/* Header file for database engine */
/* Kevin Thorley and Chris Darmetko */

/* File format conventions:
 * We will use an ascii file which stores the data in fixed length records.  The 100 bytes of the file
 * will contain the header data for the file.  This includes field lengths information.
 * The header data is formatted as a delimited list of integers specifying the field lengths.
 * In this way, the file will remain hum,an readable and therefore easier to debug.  
 * However, using fixed length fields will allow navigation and manipulation of the records easier.  
 */

/* Define error codes */
#define FILENOTFOUND -1;
#define INVALIDFIELDNUMBER -2;
#define KEYINTEGRITYERROR -3;
#define NORECORDERROR -4;

/* Database Engine Functions */
int CreateDB(char* dbName, char* datafile);

int PrintDB(char* dbName);

int RecordScan(char* dbName, int attrNumber, char* value);

int KeyScan(char* dbName, char* value);

int InsertRecord(char* dbName, char *value);

int DeleteRecord(char* dbName, char* keyValue);

int ModifyRecord(char* dbName, char* keyValue, int attrNumber, char* 
newValue);

void error(int rc);










